@@ -46,8 +46,6 @@ static QImage requestImageFromQIcon(const QString &id, QSize *size, const QSize
     } else {
         icon = DIconTheme::findQIcon(name);
     }
-    if (icon.isNull())
-        return invalidIcon(size, requestedSize);
 
     QIcon::Mode qMode = QIcon::Normal;
     QIcon::State qState = QIcon::Off;
@@ -66,6 +64,11 @@ static QImage requestImageFromQIcon(const QString &id, QSize *size, const QSize
             devicePixelRatio = 1.0;
     }
 
+    if (icon.isNull()) {
+        QSize icon_size = requestedSize;
+        return invalidIcon(size, icon_size /= devicePixelRatio);
+    }
+
     QSize icon_size = requestedSize;
     // 初始时可能没有为图标设置期望的大小
     if (icon_size.isEmpty()) {
@@ -429,6 +432,7 @@ static QPainterPath roundedRectPath(const QRectF &rect, const DQuickShadowProvid
 
 QImage DQuickShadowProvider::requestImage(const QString &id, QSize *size, const QSize &requestedSize)
 {
+    Q_UNUSED(requestedSize)
     ShadowConfig config;
     QColor color;
     qreal xOffset;
